<?php
/**
 * Active callbacks for Theme/Customzer Options
 *
 * @package Catch Themes
 * @subpackage Verity Pro
 * @since Verity Pro 1.1
 */

if ( ! function_exists( 'verity_is_hero_content_active' ) ) :
	/**
	* Return true if hero content is active
	*
	* @since Verity Pro 1.1
	*/
	function verity_is_hero_content_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option( 'page_for_posts' );

		$enable = $control->manager->get_setting( 'verity_hero_content_visibility' )->value();

		//return true only if previwed page on customizer matches the type of content option selected
		return ( 'entire-site' == $enable  || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'homepage' == $enable ) );
	}
endif;


if ( ! function_exists( 'verity_is_demo_hero_content_inactive' ) ) :
	/**
	* Return true if demo hero content is inactive
	*
	* @since Verity Pro 1.1
	*/
	function verity_is_demo_hero_content_inactive( $control ) {
		$type = $control->manager->get_setting( 'verity_hero_content_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( verity_is_hero_content_active( $control ) && !( 'demo' == $type ) );
	}
endif;


if ( ! function_exists( 'verity_is_hero_post_content_active' ) ) :
	/**
	* Return true if post content is active
	*
	* @since Verity Pro 1.1
	*/
	function verity_is_hero_post_content_active( $control ) {
		$type = $control->manager->get_setting( 'verity_hero_content_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( verity_is_hero_content_active( $control ) && 'post' == $type );
	}
endif;


if ( ! function_exists( 'verity_is_hero_page_content_active' ) ) :
	/**
	* Return true if hero page content is active
	*
	* @since Verity Pro 1.1
	*/
	function verity_is_hero_page_content_active( $control ) {
		$type = $control->manager->get_setting( 'verity_hero_content_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( verity_is_hero_content_active( $control ) && 'page' == $type );
	}
endif;


if ( ! function_exists( 'verity_is_hero_category_content_active' ) ) :
	/**
	* Return true if hero category content is active
	*
	* @since Verity Pro 1.1
	*/
	function verity_is_hero_category_content_active( $control ) {
		$type = $control->manager->get_setting( 'verity_hero_content_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( verity_is_hero_content_active( $control ) && 'category' == $type );
	}
endif;

if ( ! function_exists( 'verity_is_hero_post_page_category_content_active' ) ) :
	/**
	* Return true if hero post/page/category content is active
	*
	* @since Verity Pro 1.1
	*/
	function verity_is_hero_post_page_category_content_active( $control ) {
		$type = $control->manager->get_setting( 'verity_hero_content_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( verity_is_hero_content_active( $control ) && ( 'page' == $type || 'post' == $type || 'category' == $type ) );
	}
endif;


if ( ! function_exists( 'verity_is_hero_custom_content_active' ) ) :
	/**
	* Return true if hero custom content is active
	*
	* @since Verity Pro 1.1
	*/
	function verity_is_hero_custom_content_active( $control ) {
		$type = $control->manager->get_setting( 'verity_hero_content_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( verity_is_hero_content_active( $control ) && ( 'image' == $type ) );
	}
endif;


if( ! function_exists( 'verity_is_slider_active' ) ) :
	/**
	* Return true if slider is active
	*
	* @since Verity Pro 1.1
	*/
	function verity_is_slider_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'verity_slider_option' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( 'entire-site' == $enable || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'homepage' == $enable ) );
	}
endif;


if( ! function_exists( 'verity_is_demo_slider_inactive' ) ) :
	/**
	* Return true if demo slider is inactive
	*
	* @since Verity Pro 1.1
	*/
	function verity_is_demo_slider_inactive( $control ) {
		$type = $control->manager->get_setting( 'verity_slider_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is or is not selected type
		return ( verity_is_slider_active( $control ) && !( 'demo' == $type ) );
	}
endif;


if( ! function_exists( 'verity_is_post_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since Verity Pro 1.1
	*/
	function verity_is_post_slider_active( $control ) {
		$type = $control->manager->get_setting( 'verity_slider_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is or is not selected type
		return ( verity_is_slider_active( $control ) && ( 'post' == $type ) );
	}
endif;


if( ! function_exists( 'verity_is_page_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since Verity Pro 1.1
	*/
	function verity_is_page_slider_active( $control ) {
		$type = $control->manager->get_setting( 'verity_slider_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is or is not selected type
		return ( verity_is_slider_active( $control ) && ( 'page' == $type ) );
	}
endif;


if( ! function_exists( 'verity_is_category_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since Verity Pro 1.1
	*/
	function verity_is_category_slider_active( $control ) {
		$type = $control->manager->get_setting( 'verity_slider_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is or is not selected type
		return ( verity_is_slider_active( $control ) && ( 'category' == $type ) );
	}
endif;

if( ! function_exists( 'verity_is_page_post_category_slider_active' ) ) :
	/**
	* Return true if page/post/category slider is active
	*
	* @since Verity Pro 1.1
	*/
	function verity_is_page_post_category_slider_active( $control ) {
		$type = $control->manager->get_setting( 'verity_slider_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is or is not selected type
		return ( verity_is_slider_active( $control ) && ( 'category' == $type || 'post' == $type || 'page' == $type ) );
	}
endif;


if( ! function_exists( 'verity_is_image_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since Verity Pro 1.1
	*/
	function verity_is_image_slider_active( $control ) {
		$type = $control->manager->get_setting( 'verity_slider_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is or is not selected type
		return ( verity_is_slider_active( $control ) && ( 'image' == $type ) );
	}
endif;

if( ! function_exists( 'verity_is_featured_content_active' ) ) :
	/**
	* Return true if featured content is active
	*
	* @since Verity Pro 1.1
	*/
	function verity_is_featured_content_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'verity_featured_content_option' )->value();

		//return true only if previwed page on customizer matches the type of content option selected
		return ( 'entire-site' == $enable || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'homepage' == $enable ) );
	}
endif;


if( ! function_exists( 'verity_is_demo_featured_content_inactive' ) ) :
	/**
	* Return true if demo featured content is inactive
	*
	* @since Verity Pro 1.1
	*/
	function verity_is_demo_featured_content_inactive( $control ) {
		$type = $control->manager->get_setting( 'verity_featured_content_type' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is or is not selected type
		return ( verity_is_featured_content_active( $control ) && !( 'demo' == $type ) );
	}
endif;


if( ! function_exists( 'verity_is_featured_post_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Verity Pro 1.1
	*/
	function verity_is_featured_post_content_active( $control ) {
		$type = $control->manager->get_setting( 'verity_featured_content_type' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is or is not selected type
		return ( verity_is_featured_content_active( $control ) && ( 'post' == $type ) );
	}
endif;


if( ! function_exists( 'verity_is_featured_page_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Verity Pro 1.1
	*/
	function verity_is_featured_page_content_active( $control ) {
		$type = $control->manager->get_setting( 'verity_featured_content_type' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is or is not selected type
		return ( verity_is_featured_content_active( $control ) && ( 'page' == $type ) );
	}
endif;


if( ! function_exists( 'verity_is_featured_category_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Verity Pro 1.1
	*/
	function verity_is_featured_category_content_active( $control ) {
		$type = $control->manager->get_setting( 'verity_featured_content_type' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is or is not selected type
		return ( verity_is_featured_content_active( $control ) && ( 'category' == $type ) );
	}
endif;


if( ! function_exists( 'verity_is_featured_page_post_tag_category_content_active' ) ) :
	/**
	* Return true if page/post/category/image content is active
	*
	* @since Verity Pro 1.1
	*/
	function verity_is_featured_page_post_tag_category_content_active( $control ) {
		$type = $control->manager->get_setting( 'verity_featured_content_type' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is or is not selected type
		return ( verity_is_featured_content_active( $control ) && ( 'category' == $type || 'page' == $type ) || 'post' == $type );
	}
endif;


if( ! function_exists( 'verity_is_featured_image_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Verity Pro 1.1
	*/
	function verity_is_featured_image_content_active( $control ) {
		$type = $control->manager->get_setting( 'verity_featured_content_type' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is or is not selected type
		return ( verity_is_featured_content_active( $control ) && ( 'image' == $type ) );
	}
endif;


if( ! function_exists( 'verity_is_featured_tag_content_active' ) ) :
	/**
	* Return true if tag content is active
	*
	* @since Verity Pro 1.1
	*/
	function verity_is_featured_tag_content_active( $control ) {
		$type = $control->manager->get_setting( 'verity_featured_content_type' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is or is not selected type
		return ( verity_is_featured_content_active( $control ) && ( 'tag' == $type ) );
	}
endif;


if( ! function_exists( 'verity_is_homepage_posts_enabled' ) ) :
	/**
	* Return true if hommepage posts/content is enabled
	*
	* @since Verity Pro 1.1
	*/
	function verity_is_homepage_posts_enabled( $control ) {
		return ( ! $control->manager->get_setting( 'verity_disable_homepage_posts' )->value() );
	}
endif;
