<?php
/**
* Add Featured Content options
*
* @package Catch Themes
* @subpackage Verity Pro
* @since Verity 1.1
*/

/**
 * Add featured content options to theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function verity_featured_content_options( $wp_customize ) {
	$wp_customize->add_section( 'featured_content', array(
		'priority'      => 400,
		'title'			=> esc_html__( 'Featured Content', 'verity-pro' ),
	) );

	$def_content = 'disabled';

	if ( class_exists( 'Jetpack' ) ) {
		$def_content = 'homepage';

		$wp_customize->get_control( 'featured-content[tag-name]' )->active_callback = 'verity_is_featured_tag_content_active';
		$wp_customize->get_control( 'featured-content[hide-tag]' )->active_callback = 'verity_is_featured_tag_content_active';
		$wp_customize->get_control( 'featured-content[show-all]' )->active_callback = 'verity_is_featured_tag_content_active';
	}

	$wp_customize->add_setting( 'verity_featured_content_option', array(
		'default'			=> $def_content,
		'sanitize_callback' => 'verity_sanitize_select',
	) );

	$wp_customize->add_control( 'verity_featured_content_option', array(
		'choices'  	=> verity_section_visibility_options(),
		'label'    	=> esc_html__( 'Enable on', 'verity-pro' ),
		'section'  	=> 'featured_content',
		'type'	  	=> 'select',
	) );

	$wp_customize->add_setting( 'verity_featured_content_layout', array(
		'default'			=> 'layout-three',
		'sanitize_callback' => 'verity_sanitize_select',
	) );

	$wp_customize->add_control( 'verity_featured_content_layout', array(
		'active_callback' => 'verity_is_featured_content_active',
		'choices'         => verity_featured_content_layout_options(),
		'label'           => esc_html__( 'Select Featured Content Layout', 'verity-pro' ),
		'section'         => 'featured_content',
		'type'            => 'select',
	) );

	$wp_customize->add_setting( 'verity_featured_content_archive_title', array(
        'default'           => esc_html__( 'Featured', 'verity-pro' ),
        'sanitize_callback' => 'wp_kses_post',
    ) );

    $wp_customize->add_control( 'verity_featured_content_archive_title', array(
		'active_callback' => 'verity_is_featured_content_active',
		'label'           => esc_html__( 'Featured Content Title', 'verity-pro' ),
		'section'         => 'featured_content',
		'type'            => 'text',
    ) );

	$wp_customize->add_setting( 'verity_featured_content_sub_title', array(
		'sanitize_callback'	=> 'wp_kses_post',
	) );

	$wp_customize->add_control( 'verity_featured_content_sub_title' , array(
			'active_callback' => 'verity_is_featured_content_active',
			'label'           => esc_html__( 'Featured Content Sub Title', 'verity-pro' ),
			'section'         => 'featured_content',
			'type'            => 'text',
		)
	);

	$type = verity_section_type_options();

	$def_type = 'category';

	unset( $type['demo'] );

	if ( class_exists( 'Jetpack' ) ) {
		$def_type    = 'tag';
		$type['tag'] = esc_html__( 'Tags(via Jetpack)', 'verity-pro' );
	}

	$wp_customize->add_setting( 'verity_featured_content_type', array(
		'default'			=> $def_type,
		'sanitize_callback'	=> 'verity_sanitize_select',
	) );

	$wp_customize->add_control( 'verity_featured_content_type', array(
		'active_callback' => 'verity_is_featured_content_active',
		'choices'         => $type,
		'label'           => esc_html__( 'Select Content Type', 'verity-pro' ),
		'section'         => 'featured_content',
		'type'            => 'select',
	) );

	$wp_customize->add_setting( 'verity_featured_content_number', array(
		'default'			=> 3,
		'sanitize_callback'	=> 'verity_sanitize_number_range',
	) );

	$wp_customize->add_control( 'verity_featured_content_number' , array(
			'active_callback' => 'verity_is_demo_featured_content_inactive',
			'description'     => esc_html__( 'Save and refresh the page if No. of Featured Content is changed (Max no of Featured Content is 20)', 'verity-pro' ),
			'input_attrs'     => array(
				'style' => 'width: 100px;',
				'min'   => 0,
				'max'   => 20,
				'step'  => 1,
			),
			'label'           => esc_html__( 'No of Featured Content', 'verity-pro' ),
			'section'         => 'featured_content',
			'type'            => 'number',
			'transport'       => 'postMessage'
		)
	);

	$wp_customize->add_setting( 'verity_featured_content_show', array(
		'default'			=> 'hide-content',
		'sanitize_callback'	=> 'verity_sanitize_select',
	) );

	$wp_customize->add_control( 'verity_featured_content_show', array(
		'active_callback' => 'verity_is_featured_page_post_tag_category_content_active',
		'choices'         => verity_content_show(),
		'label'           => esc_html__( 'Display Content', 'verity-pro' ),
		'section'         => 'featured_content',
		'type'            => 'select',
	) );

	$wp_customize->add_setting( 'verity_featured_content_select_category', array(
		'sanitize_callback' => 'verity_sanitize_category_list',
	) );

	$wp_customize->add_control( new VerityCustomizeDropdownCategoriesControl( $wp_customize, 'verity_featured_content_select_category', array(
		'active_callback' => 'verity_is_featured_category_content_active',
		'label'           => esc_html__( 'Select Categories', 'verity-pro' ),
		'name'            => 'verity_featured_content_select_category',
		'section'         => 'featured_content',
		'type'            => 'dropdown-categories',
	) ) );

	$number = get_theme_mod( 'verity_featured_content_number', 3 );

	//loop for featured post content
	for ( $i=1; $i <=  $number ; $i++ ) {
		$wp_customize->add_setting( 'verity_featured_content_post_'. $i, array(
				'sanitize_callback' => 'verity_sanitize_post',
			)
		);

		$wp_customize->add_control( 'verity_featured_content_post_'. $i, array(
				'active_callback' => 'verity_is_featured_post_content_active',
				'input_attrs'     => array(
					'style' => 'width: 40px;'
				),
				'label'           => esc_html__( 'Post', 'verity-pro' ) . ' ' . $i ,
				'section'         => 'featured_content',
				'choices'         => verity_posts_list(),
        		'type'            => 'select'
			)
		);

		$wp_customize->add_setting( 'verity_featured_content_page_'. $i, array(
			'sanitize_callback' => 'verity_sanitize_post',
		) );

		$wp_customize->add_control( 'verity_featured_content_page_'. $i, array(
			'active_callback' => 'verity_is_featured_page_content_active',
			'label'           => esc_html__( 'Featured Page', 'verity-pro' ) . ' ' . $i ,
			'section'         => 'featured_content',
			'type'            => 'dropdown-pages',
		) );

		$wp_customize->add_setting( 'verity_featured_content_note_'. $i, array(
			'sanitize_callback'	=> 'sanitize_text_field',
		) );

		$wp_customize->add_control( new VerityNoteControl( $wp_customize, 'verity_featured_content_note_'. $i, array(
			'active_callback' => 'verity_is_featured_image_content_active',
			'label'           => esc_html__( 'Featured Content #', 'verity-pro' ) .  $i,
			'section'         => 'featured_content',
			'type'            => 'description',
			) ) );

		$wp_customize->add_setting( 'verity_featured_content_image_'. $i, array(
			'sanitize_callback'	=> 'verity_sanitize_image',
		) );

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'verity_featured_content_image_'. $i , array(
			'active_callback' => 'verity_is_featured_image_content_active',
			'label'           => esc_html__( 'Image', 'verity-pro' ),
			'section'         => 'featured_content',
		) ) );

		$wp_customize->add_setting( 'verity_featured_content_link_'. $i, array(
			'sanitize_callback'	=> 'esc_url_raw',
		) );

		$wp_customize->add_control(  'verity_featured_content_link_'. $i, array(
			'active_callback' => 'verity_is_featured_image_content_active',
			'label'           => esc_html__( 'Link', 'verity-pro' ),
			'section'         => 'featured_content',
		) );

		$wp_customize->add_setting( 'verity_featured_content_target_'. $i, array(

			'sanitize_callback'	=> 'verity_sanitize_checkbox',
		) );

		$wp_customize->add_control(  'verity_featured_content_target_'. $i, array(
			'active_callback' => 'verity_is_featured_image_content_active',
			'label'           => esc_html__( 'Check to Open Link in New Window/Tab', 'verity-pro' ),
			'section'         => 'featured_content',
			'type'            => 'checkbox',
	    ) );

	    $wp_customize->add_setting( 'verity_featured_content_title_'. $i, array(
			'sanitize_callback'	=> 'wp_kses_post',
		) );

		$wp_customize->add_control(  'verity_featured_content_title_'. $i, array(
			'active_callback' => 'verity_is_featured_image_content_active',
			'label'           => esc_html__( 'Title', 'verity-pro' ),
			'section'         => 'featured_content',
			'type'            => 'text',
		) );

	    $wp_customize->add_setting( 'verity_featured_content_content_'. $i, array(
			'sanitize_callback'	=> 'wp_kses_post',
		) );

		$wp_customize->add_control( 'verity_featured_content_content_'. $i, array(
			'active_callback' => 'verity_is_featured_image_content_active',
			'label'           => esc_html__( 'Content', 'verity-pro' ),
			'section'         => 'featured_content',
			'type'            => 'textarea',
	    ) );
	}
}
add_action( 'customize_register', 'verity_featured_content_options' );


/**
 * Returns an array of featured content options
 *
 * @since Verity 1.1
 */
function verity_featured_content_layout_options() {
	$options = array(
		'layout-two'   => esc_html__( '2 columns', 'verity-pro' ),
		'layout-three' => esc_html__( '3 columns', 'verity-pro' ),
		'layout-four'  => esc_html__( '4 columns', 'verity-pro' ),
	);

	return apply_filters( 'verity_featured_content_layout_options', $options );
}
