<?php
/**
 * Verity Pro Hero Content Options
 * @package Verity Pro
 */

/**
 * Add hero content options to theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function verity_slider_options( $wp_customize ) {
	$wp_customize->add_section( 'verity_slider', array(
		'priority'      => 500,
		'title'			=> esc_html__( 'Featured Slider', 'verity-pro' ),
	) );

	$wp_customize->add_setting( 'verity_slider_option', array(
		'default'			=> 'disabled',
		'sanitize_callback' => 'verity_sanitize_select',
	) );

	$wp_customize->add_control( 'verity_slider_option', array(
		'choices'   => verity_section_visibility_options(),
		'label'    	=> esc_html__( 'Enable on', 'verity-pro' ),
		'section'  	=> 'verity_slider',
		'type'    	=> 'select',
	) );

	$wp_customize->add_setting( 'verity_slider_transition_effect', array(
		'default'			=> 'fade',
		'sanitize_callback'	=> 'verity_sanitize_select',
	) );

	$wp_customize->add_control( 'verity_slider_transition_effect' , array(
		'active_callback' => 'verity_is_slider_active',
		'choices'         => verity_slider_transition_effects(),
		'label'           => esc_html__( 'Transition Effect', 'verity-pro' ),
		'section'         => 'verity_slider',
		'type'            => 'select',
		)
	);

	$wp_customize->add_setting( 'verity_slider_transition_delay', array(
		'default'			=> '4',
		'sanitize_callback'	=> 'absint',
	) );

	$wp_customize->add_control( 'verity_slider_transition_delay' , array(
		'active_callback'	=> 'verity_is_slider_active',
		'description'	=> esc_html__( 'seconds(s)', 'verity-pro' ),
		'input_attrs' => array(
        	'style' => 'width: 40px;'
    	),
    	'label'    		=> esc_html__( 'Transition Delay', 'verity-pro' ),
		'section'  		=> 'verity_slider',
		)
	);

	$wp_customize->add_setting( 'verity_slider_transition_length', array(
		'default'			=> '1',
		'sanitize_callback'	=> 'absint',
	) );

	$wp_customize->add_control( 'verity_slider_transition_length' , array(
		'active_callback' => 'verity_is_slider_active',
		'description'     => esc_html__( 'seconds(s)', 'verity-pro' ),
		'input_attrs'     => array(
        	'style' => 'width: 100px;'
    	),
    	'label'    		=> esc_html__( 'Transition Length', 'verity-pro' ),
		'section'  		=> 'verity_slider',
		)
	);

	$wp_customize->add_setting( 'verity_slider_image_loader', array(
		'default'			=> 'false',
		'sanitize_callback' => 'verity_sanitize_select',
	) );

	$wp_customize->add_control( 'verity_slider_image_loader', array(
		'active_callback' => 'verity_is_slider_active',
		'choices'         => verity_slider_image_loader(),
		'label'           => esc_html__( 'Image Loader', 'verity-pro' ),
		'section'         => 'verity_slider',
		'type'            => 'select',
	) );

	$wp_customize->add_setting( 'verity_slider_type', array(
		'default'			=> 'demo',
		'sanitize_callback'	=> 'verity_sanitize_select',
	) );

	$wp_customize->add_control( 'verity_slider_type', array(
		'active_callback' => 'verity_is_slider_active',
		'choices'         => verity_section_type_options(),
		'label'           => esc_html__( 'Select Slider Type', 'verity-pro' ),
		'section'         => 'verity_slider',
		'type'            => 'select',
	) );

	$wp_customize->add_setting( 'verity_slider_number', array(
		'default'			=> '4',
		'sanitize_callback'	=> 'verity_sanitize_number_range',
	) );

	$wp_customize->add_control( 'verity_slider_number' , array(
			'active_callback' => 'verity_is_demo_slider_inactive',
			'description'     => esc_html__( 'Save and refresh the page if No. of Slides is changed (Max no of slides is 20)', 'verity-pro' ),
			'input_attrs'     => array(
	            'style' => 'width: 45px;',
	            'min'   => 0,
	            'max'   => 20,
	            'step'  => 1,
	        	),
			'label'    		=> esc_html__( 'No of Slides', 'verity-pro' ),
			'section'  		=> 'verity_slider',
			'type'	   		=> 'number',
			'transport'		=> 'postMessage'
		)
	);

	$wp_customize->add_setting( 'verity_slider_content_show', array(
		'default'			=> 'excerpt',
		'sanitize_callback'	=> 'verity_sanitize_select',
	) );

	$wp_customize->add_control( 'verity_slider_content_show', array(
		'active_callback' => 'verity_is_page_post_category_slider_active',
		'choices'         => verity_content_show(),
		'label'           => esc_html__( 'Display Content', 'verity-pro' ),
		'section'         => 'verity_slider',
		'type'            => 'select',
	) );

	$wp_customize->add_setting( 'verity_exclude_slider_post', array(
		'sanitize_callback'	=> 'verity_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'verity_exclude_slider_post', array(
		'active_callback'	=> 'verity_is_post_slider_active',
		'label'		=> esc_html__( 'Check to exclude Slider post from Homepage posts', 'verity-pro' ),
		'section'   => 'verity_slider',
		'type'		=> 'checkbox',
	) );

	$wp_customize->add_setting( 'verity_slider_select_category', array(
		'sanitize_callback'	=> 'verity_sanitize_category_list',
	) );

	$wp_customize->add_control( new VerityCustomizeDropdownCategoriesControl( $wp_customize, 'verity_slider_select_category', array(
		'active_callback' => 'verity_is_category_slider_active',
		'label'           => esc_html__('Select Categories', 'verity-pro' ),
		'name'            => 'verity_slider_select_category',
		'section'         => 'verity_slider',
		'type'            => 'dropdown-categories',
    ) ) );

	$slider_number = get_theme_mod( 'verity_slider_number', 4 );

	for ( $i=1; $i <= $slider_number ; $i++ ) {
		// Post Sliders
		$wp_customize->add_setting( 'verity_slider_post_'. $i, array(
			'sanitize_callback'	=> 'verity_sanitize_post',
		) );

		$wp_customize->add_control( 'verity_slider_post_'. $i, array(
			'active_callback'	=> 'verity_is_post_slider_active',
			'input_attrs' => array(
        		'style' => 'width: 80px;'
    		),
			'label'    	=> esc_html__( 'Post', 'verity-pro' ) . ' # ' . $i,
			'section'  	=> 'verity_slider',
			'type'	   	=> 'text',
			)
		);

		// Page Sliders
		$wp_customize->add_setting( 'verity_slider_page_'. $i, array(
			'sanitize_callback'	=> 'verity_sanitize_post',
		) );

		$wp_customize->add_control( 'verity_slider_page_'. $i, array(
			'active_callback'	=> 'verity_is_page_slider_active',
			'label'    	=> esc_html__( 'Page', 'verity-pro' ) . ' # ' . $i,
			'section'  	=> 'verity_slider',
			'type'	   	=> 'dropdown-pages',
		) );

		// Image Sliders
		$wp_customize->add_setting( 'verity_slider_note_'. $i, array(
			'sanitize_callback'	=> 'sanitize_text_field',
		) );

		$wp_customize->add_control( new VerityNoteControl( $wp_customize, 'featured_slider_note_'. $i, array(
			'active_callback' => 'verity_is_image_slider_active',
			'label'           => esc_html__( 'Slide #', 'verity-pro' ) . $i,
			'section'         => 'verity_slider',
			'type'            => 'description',
   		) ) );

		$wp_customize->add_setting( 'verity_slider_image_'. $i, array(
			'sanitize_callback'	=> 'verity_sanitize_image',
		) );

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'verity_slider_image_'. $i, array(
			'active_callback' => 'verity_is_image_slider_active',
			'label'           => esc_html__( 'Image', 'verity-pro' ),
			'section'         => 'verity_slider',
		) ) );

		$wp_customize->add_setting( 'verity_featured_link_'. $i, array(
			'sanitize_callback'	=> 'esc_url_raw',
		) );

		$wp_customize->add_control(  'verity_featured_link_'. $i, array(
			'active_callback' => 'verity_is_image_slider_active',
			'label'           => esc_html__( 'Link', 'verity-pro' ),
			'section'         => 'verity_slider',
		) );

		$wp_customize->add_setting( 'verity_featured_target_'. $i, array(
			'sanitize_callback'	=> 'verity_sanitize_checkbox',
		) );

		$wp_customize->add_control(  'verity_featured_target_'. $i, array(
			'active_callback'	=> 'verity_is_image_slider_active',
			'label'		=> esc_html__( 'Check to Open Link in New Window/Tab', 'verity-pro' ),
			'section'   => 'verity_slider',
			'type'		=> 'checkbox',
	    ) );

	    $wp_customize->add_setting( 'verity_featured_title_'. $i, array(
			'sanitize_callback'	=> 'sanitize_text_field',
		) );

		$wp_customize->add_control(  'verity_featured_title_'. $i, array(
			'active_callback'	=> 'verity_is_image_slider_active',
			'label'		=> esc_html__( 'Title', 'verity-pro' ),
			'section'   => 'verity_slider',
			'type'		=> 'text',
	    ) );

	    $wp_customize->add_setting( 'verity_featured_content_'. $i, array(
			'sanitize_callback'	=> 'sanitize_text_field',
		) );

		$wp_customize->add_control( 'verity_featured_content_'. $i, array(
			'active_callback'	=> 'verity_is_image_slider_active',
			'label'		=> esc_html__( 'Content', 'verity-pro' ),
			'section'   => 'verity_slider',
			'type'		=> 'textarea',
	    ) );
	}
}
add_action( 'customize_register', 'verity_slider_options' );


/**
 * Returns an array of feature slider transition effects
 *
 * @since Verity Pro 1.1
 */
function verity_slider_transition_effects() {
	$options = array(
		'fade'       => esc_html__( 'Fade', 'verity-pro' ),
		'fadeout'    => esc_html__( 'Fade Out', 'verity-pro' ),
		'none'       => esc_html__( 'None', 'verity-pro' ),
		'scrollHorz' => esc_html__( 'Scroll Horizontal', 'verity-pro' ),
		'scrollVert' => esc_html__( 'Scroll Vertical', 'verity-pro' ),
		'flipHorz'   => esc_html__( 'Flip Horizontal', 'verity-pro' ),
		'flipVert'   => esc_html__( 'Flip Vertical', 'verity-pro' ),
		'tileSlide'  => esc_html__( 'Tile Slide', 'verity-pro' ),
		'tileBlind'  => esc_html__( 'Tile Blind', 'verity-pro' ),
		'shuffle'    => esc_html__( 'Shuffle', 'verity-pro' ),
	);

	return apply_filters( 'verity_slider_transition_effects', $options );
}


/**
 * Returns an array of featured slider image loader options
 *
 * @since Verity Pro 1.1
 */
function verity_slider_image_loader() {
	$options = array(
		'true'  => esc_html__( 'True', 'verity-pro' ),
		'wait'  => esc_html__( 'Wait', 'verity-pro' ),
		'false' => esc_html__( 'False', 'verity-pro' ),
	);

	return apply_filters( 'verity_slider_image_loader', $options );
}


/**
 * Returns an array of featured content show registered for Lucida.
 *
 * @since Verity Pro 1.1
 */
function verity_content_show() {
	$options = array(
		'excerpt'      => esc_html__( 'Show Excerpt', 'verity-pro' ),
		'full-content' => esc_html__( 'Show Full Content', 'verity-pro' ),
		'hide-content' => esc_html__( 'Hide Content', 'verity-pro' ),
	);

	return apply_filters( 'verity_content_show', $options );
}
