<?php

if( ! function_exists( 'verity_posts_list' ) ) {

    /**
     * Create array of posts used for customizer
     * 
     * @return string array of posts
     */
    function verity_posts_list() {

        $args = array(
            'posts_per_page' => -1,
            'post_status'    => 'publish',
            'order'          => 'ASC',
            'orderby'        => 'post_title',
            'cache_results'  => true,
        );

        $posts  = get_posts( $args );
        $output['0']= esc_html__( '-- Select --', 'verity-pro' );

        if( ! empty($posts) ) {
            foreach( (array) $posts as $post ) {
                $output[ $post->ID ] = ! empty( $post->post_title ) ? $post->post_title : sprintf( __( '#%d (no title)', 'verity-pro' ), $post->ID );
            }
        }
        return $output;
    }

}


/**
 * Returns an array of visibility options for featured sections
 *
 * @since Verity Pro 1.1
 */
function verity_section_visibility_options() {
    $options = array(
        'homepage'    => esc_html__( 'Homepage / Frontpage', 'verity-pro' ),
        'entire-site' => esc_html__( 'Entire Site', 'verity-pro' ),
        'disabled'    => esc_html__( 'Disabled', 'verity-pro' ),
    );

    return apply_filters( 'verity_section_visibility_options', $options );
}

/**
 * Returns an array of section types
 *
 * @since Verity Pro 1.1
 */
function verity_section_type_options() {
    $options = array(
        'demo'     => esc_html__( 'Demo', 'verity-pro' ),
        'post'     => esc_html__( 'Post', 'verity-pro' ),
        'page'     => esc_html__( 'Page', 'verity-pro' ),
        'category' => esc_html__( 'Category', 'verity-pro' ),
        'image'    => esc_html__( 'Image', 'verity-pro' ),
    );

    return apply_filters( 'verity_section_type_options', $options );
}

/**
 * Returns an array of comment options for verity.
 *
 * @since Verity Pro 1.1
 */
function verity_comment_options() {
    $comment_options = array(
        'use-wordpress-setting' => esc_html__( 'Use WordPress Setting', 'verity-pro' ),
        'disable-in-pages'      => esc_html__( 'Disable in Pages', 'verity-pro' ),
        'disable-completely'    => esc_html__( 'Disable Completely', 'verity-pro' ),
    );

    return apply_filters( 'verity_comment_options', $comment_options );
}

/**
 * Returns an array of color schemes registered for catchresponsive.
 *
 * @since Verity 1.1
 */
function verity_get_pagination_types() {
    $pagination_types = array(
        'default'                => esc_html__( 'Default(Older Posts/Newer Posts)', 'verity-pro' ),
        'numeric'                => esc_html__( 'Numeric', 'verity-pro' ),
        'infinite-scroll-click'  => esc_html__( 'Infinite Scroll (Click)', 'verity-pro' ),
        'infinite-scroll-scroll' => esc_html__( 'Infinite Scroll (Scroll)', 'verity-pro' ),
    );

    return apply_filters( 'verity_get_pagination_types', $pagination_types );
}