<?php
/**
 * Verity Pro Theme Options
 *
 * @package Verity Pro
 */

/**
 * Add theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function verity_theme_options( $wp_customize ) {
	$wp_customize->add_panel( 'verity_theme_options', array(
        'title'    => esc_html__( 'Theme Options', 'verity-pro' ),
        'priority' => 130,
    ) );

    // Breadcrumb Option
    $wp_customize->add_section( 'verity_breadcrumb_options', array(
        'description'   => esc_html__( 'Breadcrumbs are a great way of letting your visitors find out where they are on your site with just a glance. You can enable/disable them on homepage and entire site.', 'verity-pro' ),
        'panel'         => 'verity_theme_options',
        'title'         => esc_html__( 'Breadcrumb', 'verity-pro' ),
    ) );

    $wp_customize->add_setting( 'verity_breadcrumb_option', array(
        'default'           => 1,
        'sanitize_callback' => 'verity_sanitize_checkbox'
    ) );

    $wp_customize->add_control( 'verity_breadcrumb_option', array(
        'label'    => esc_html__( 'Check to enable Breadcrumb', 'verity-pro' ),
        'section'  => 'verity_breadcrumb_options',
        'type'     => 'checkbox',
    ) );
    // Breadcrumb Option End

    // Font Family Options
    $wp_customize->add_section( 'verity_font_family', array(
        'panel' => 'verity_theme_options',
        'title' => esc_html__( 'Font Family Options', 'verity-pro' ),
    ) );

    $avaliable_fonts = verity_avaliable_fonts();

    $choices = array();

    foreach ( $avaliable_fonts as $font ) {
        $choices[ $font[ 'value' ] ] = str_replace( '"', '', $font[ 'label' ] );
    }

    $font_family_options = verity_font_family_options();

    foreach ( $font_family_options as $key => $value ) {
        $wp_customize->add_setting( $key, array(
            'default'           => $value['default'],
            'sanitize_callback' => 'verity_sanitize_select',
        ) );

        $wp_customize->add_control( $key, array(
            'choices'  => $choices,
            'label'    => $value['label'],
            'section'  => 'verity_font_family',
            'type'     => 'select',
        ) );
    }

    $wp_customize->add_setting( 'verity_reset_typography', array(
        'sanitize_callback' => 'verity_sanitize_checkbox',
        'transport'         => 'postMessage',
    ) );

    $wp_customize->add_control( 'verity_reset_typography', array(
        'label'    => esc_html__( 'Check to reset fonts', 'verity-pro' ),
        'section'  => 'verity_font_family',
        'type'     => 'checkbox',
    ) );
    // Font Family Options End

    // Footer Editor Options
    $wp_customize->add_section( 'verity_footer_editor_options', array(
        'title'       => esc_html__( 'Footer Editor Options', 'verity-pro' ),
        'description' => esc_html__( 'You can either add html or plain text', 'verity-pro'),
        'panel'       => 'verity_theme_options'
    ) );

    $theme_data = wp_get_theme();

    $def_footer_text = sprintf( _x( 'Copyright &copy; %1$s %2$s. All Rights Reserved', '1: Year, 2: Site Title with home URL', 'verity-pro' ), '[the-year]', '[site-link]' ) . ' &#124; ' . $theme_data->get( 'Name') . '&nbsp;' . esc_html__( 'by', 'verity-pro' ). '&nbsp;<a target="_blank" href="'. $theme_data->get( 'AuthorURI' ) .'">'. $theme_data->get( 'Author' ) .'</a>';

    $wp_customize->add_setting( 'verity_footer_content', array(
        'default'           => $def_footer_text,
        'sanitize_callback' => 'wp_kses_post',
    ) );

    $wp_customize->add_control( 'verity_footer_content', array(
        'description' => esc_html__( 'You can add custom shortcodes, which will be automatically inserted into your theme. Some shorcodes: [the-year] and [site-link] for current year and site link respectively.', 'verity-pro' ),
        'label'       => esc_html__( 'Footer content', 'verity-pro' ),
        'section'     => 'verity_footer_editor_options',
        'type'        => 'textarea',
    ) );

    $wp_customize->add_setting( 'verity_reset_footer_content', array(
        'sanitize_callback' => 'verity_sanitize_checkbox',
        'transport'         => 'postMessage'
    ) );

    $wp_customize->add_control( 'verity_reset_footer_content', array(
        'label'     => esc_html__( 'Check to reset Footer Content', 'verity-pro' ),
        'section'   => 'verity_footer_editor_options',
        'type'      => 'checkbox',
    ) );
    // Footer Editor Options End

    $wp_customize->add_section( 'verity_header_media_options', array(
        'title' => esc_html__( 'Header Media Options', 'verity-pro' ),
        'panel' => 'verity_theme_options'
    ) );

    $wp_customize->add_setting( 'verity_header_media_text', array(
        'default'           => esc_html__( 'This is Header Media Text and can edit this from Appearance - Customize - Theme Options - Header Media Options - Header Media Text', 'verity-pro' ),
        'sanitize_callback' => 'wp_kses_post',
    ) );
    $wp_customize->add_control( 'verity_header_media_text', array(
        'label'   => esc_html__( 'Header Media Text', 'verity-pro' ),
        'section' => 'verity_header_media_options',
        'type'    => 'textarea',
    ) );

    $wp_customize->add_section( 'verity_menu_options', array(
        'title' => esc_html__( 'Menu Options', 'verity-pro' ),
        'panel' => 'verity_theme_options'
    ) );

    /* Menu Type */
    $wp_customize->add_setting( 'verity_menu_type', array(
        'default'           => 'default',
        'sanitize_callback' => 'verity_sanitize_select',
    ) );

    $wp_customize->add_control( 'verity_menu_type', array(
        'label'    => esc_html__( 'Menu Type', 'verity-pro' ),
        'section'  => 'verity_menu_options',
        'type'     => 'radio',
        'choices'  => array(
            'default' => esc_html__( 'Default', 'verity-pro' ),
            'classic' => esc_html__( 'Classic', 'verity-pro' ),
        ),
    ) );

    $wp_customize->add_section( 'verity_layout_options', array(
        'title' => esc_html__( 'Layout Options', 'verity-pro' ),
        'panel' => 'verity_theme_options'
    ) );

    /* Layout Type */
    $wp_customize->add_setting( 'verity_layout_type', array(
        'default'           => 'boxed',
        'sanitize_callback' => 'verity_sanitize_select',
    ) );

    $wp_customize->add_control( 'verity_layout_type', array(
        'label'    => esc_html__( 'Site Layout', 'verity-pro' ),
        'section'  => 'verity_layout_options',
        'type'     => 'radio',
        'choices'  => array(
            'boxed'      => esc_html__( 'Boxed', 'verity-pro' ),
            'full-width' => esc_html__( 'Full Width', 'verity-pro' ),
        ),
    ) );

    /* Default Layout */
    $wp_customize->add_setting( 'verity_default_layout', array(
        'default'           => 'no-sidebar',
        'sanitize_callback' => 'verity_sanitize_select',
    ) );

    $wp_customize->add_control( 'verity_default_layout', array(
        'description'       => esc_html__( 'Layout for Singular Post Types like Post, Page', 'verity-pro' ),
         'label'    => esc_html__( 'Singular Content Layout', 'verity-pro' ),
        'section'  => 'verity_layout_options',
        'type'     => 'radio',
        'choices'  => array(
            'left-sidebar'          => esc_html__( 'Left Sidebar ( Primary Sidebar, Content )', 'verity-pro' ),
            'no-sidebar'            => esc_html__( 'No Sidebar', 'verity-pro' ),
            'no-sidebar-full-width' => esc_html__( 'No Sidebar: Full Width', 'verity-pro' ),
            'right-sidebar'         => esc_html__( 'Right Sidebar ( Content, Primary Sidebar )', 'verity-pro' ),
        ),
    ) );

    // Excerpt Options
    $wp_customize->add_section( 'verity_excerpt_options', array(
        'panel'     => 'verity_theme_options',
        'title'     => esc_html__( 'Excerpt Options', 'verity-pro' ),
    ) );

    $wp_customize->add_setting( 'verity_excerpt_length', array(
        'default'           => '30',
        'sanitize_callback' => 'absint',
    ) );

    $wp_customize->add_control( 'verity_excerpt_length', array(
        'description' => esc_html__('Excerpt length. Default is 30 words', 'verity-pro'),
        'input_attrs' => array(
            'min'   => 10,
            'max'   => 200,
            'step'  => 5,
            'style' => 'width: 60px;'
            ),
        'label'    => esc_html__( 'Excerpt Length (words)', 'verity-pro' ),
        'section'  => 'verity_excerpt_options',
        'type'     => 'number',
        )
    );

    $wp_customize->add_setting( 'verity_excerpt_more_text', array(
        'default'           => esc_html__( 'Continue reading', 'verity-pro' ),
        'sanitize_callback' => 'sanitize_text_field',
    ) );

    $wp_customize->add_control( 'verity_excerpt_more_text', array(
        'label'    => esc_html__( 'Read More Text', 'verity-pro' ),
        'section'  => 'verity_excerpt_options',
        'type'     => 'text',
    ) );
    // Excerpt Options End

    // Comment Option
    $wp_customize->add_section( 'verity_comment_option', array(
        'description'   => esc_html__( 'Comments can also be disabled on a per post/page basis when creating/editing posts/pages.', 'verity-pro' ),
        'panel'         => 'verity_theme_options',
        'title'         => esc_html__( 'Comment Options', 'verity-pro' ),
    ) );

    $wp_customize->add_setting( 'verity_comment_option', array(
        'default'           => 'use-wordpress-setting',
        'sanitize_callback' => 'verity_sanitize_select',
    ) );

    $wp_customize->add_control( 'verity_comment_option', array(
            'choices'   => verity_comment_options(),
            'label'     => __( 'Comment Option', 'verity-pro' ),
            'section'   => 'verity_comment_option',
            'type'      => 'select',
    ) );

    $wp_customize->add_setting( 'verity_disable_notes', array(
        'sanitize_callback' => 'catchresponsive_sanitize_checkbox',
    ) );

    $wp_customize->add_control( 'verity_disable_notes', array(
        'label'     => esc_html__( 'Check to Disable Notes', 'verity-pro' ),
        'section'   => 'verity_comment_option',
        'type'      => 'checkbox',
    ) );

    $wp_customize->add_setting( 'verity_website_field', array(
        'sanitize_callback' => 'verity_sanitize_checkbox',
    ) );

    $wp_customize->add_control( 'verity_website_field', array(
        'label'     => esc_html__( 'Check to Disable Website Field', 'verity-pro' ),
        'section'   => 'verity_comment_option',
        'type'      => 'checkbox',
    ) );
    // Comment End

    /* Feed Redirect */
    $wp_customize->add_section( 'verity_feed_redirect_options', array(
        'title' => esc_html__( 'Feed Redirect', 'verity-pro' ),
        'description'   => esc_html__( 'If your custom feed(s) are not handled by Feedblitz or Feedburner, do not use the redirect options.', 'verity-pro' ),
        'panel' => 'verity_theme_options'
    ) );

    $wp_customize->add_setting( 'verity_feed_redirect', array(
        'default'           => '',
        'sanitize_callback' => 'esc_url_raw',
    ) );

    $wp_customize->add_control( 'verity_feed_redirect', array(
        'label'    => esc_html__( 'Feed Redirect', 'verity-pro' ),
        'section'  => 'verity_feed_redirect_options',
        'type'     => 'text'
    ) );
    /* Feed Redirect End */

    //Homepage / Frontpage Options
    $wp_customize->add_section( 'verity_homepage_options', array(
        'description' => esc_html__( 'Only posts that belong to the categories selected here will be displayed on the front page', 'verity-pro' ),
        'panel'       => 'verity_theme_options',
        'title'       => esc_html__( 'Homepage / Frontpage Options', 'verity-pro' ),
    ) );

    $wp_customize->add_setting( 'verity_disable_homepage_posts', array(
        'sanitize_callback' => 'verity_sanitize_checkbox',
    ) );

    $wp_customize->add_control( 'verity_disable_homepage_posts', array(
        'label'   => esc_html__( 'Check to disable Recent Posts/Content on homepage', 'verity-pro' ),
        'section' => 'verity_homepage_options',
        'type'    => 'checkbox',
    ) );

    $wp_customize->add_setting( 'verity_front_page_category', array(
        'default'           => array(),
        'sanitize_callback' => 'verity_sanitize_category_list',
    ) );

    $wp_customize->add_control( new VerityCustomizeDropdownCategoriesControl( $wp_customize, 'verity_front_page_category', array(
        'active_callback' => 'verity_is_homepage_posts_enabled',
        'label'           => esc_html__( 'Select Categories', 'verity-pro' ),
        'name'            => 'verity_front_page_category',
        'section'         => 'verity_homepage_options',
        'type'            => 'dropdown-categories',
    ) ) );

    $wp_customize->add_setting( 'verity_disable_static_page_posts', array(
        'default'           => 1,
        'sanitize_callback' => 'verity_sanitize_checkbox',
    ) );

    $wp_customize->add_control( 'verity_disable_static_page_posts', array(
        'active_callback' => is_front_page(),
        'label'           => esc_html__( 'Check to disable Recent Posts on Static Frontpage', 'verity-pro' ),
        'section'         => 'verity_homepage_options',
        'type'            => 'checkbox',
    ) );
    //Homepage / Frontpage Settings End

    // Pagination Options
    $nav_desc = sprintf( esc_html__( 'Infinite Scroll Options requires %1$sJetPack Plugin%2$s with Infinite Scroll module Enabled.', 'verity-pro' ), '<a target="_blank" href="' . esc_url( 'https://wordpress.org/plugins/jetpack/' ) . '">', '</a>' );

    $wp_customize->add_section( 'verity_pagination_options', array(
        'description'   => $nav_desc,
        'panel'         => 'verity_theme_options',
        'title'         => esc_html__( 'Pagination Options', 'verity-pro' ),
    ) );

    $def_pagination = 'default';

    if ( class_exists( 'Jetpack' ) ) {
        $def_pagination = 'infinite-scroll-click';
    }

    $wp_customize->add_setting( 'verity_pagination_type', array(
        'default'           => $def_pagination,
        'sanitize_callback' => 'verity_sanitize_select',
    ) );

    $wp_customize->add_control( 'verity_pagination_type', array(
        'choices'  => verity_get_pagination_types(),
        'label'    => esc_html__( 'Pagination type', 'verity-pro' ),
        'section'  => 'verity_pagination_options',
        'type'     => 'select',
    ) );
    // Pagination Options End

    // For WooCommerce layout: verity_woocommerce_layout, check woocommerce-options.php

    /* Scrollup Options */
    $wp_customize->add_section( 'verity_scrollup', array(
        'panel'    => 'verity_theme_options',
        'title'    => esc_html__( 'Scrollup Options', 'verity-pro' ),
    ) );

    $wp_customize->add_setting( 'verity_disable_scrollup', array(
        'sanitize_callback' => 'verity_sanitize_checkbox',
    ) );

    $wp_customize->add_control( 'verity_disable_scrollup', array(
        'label'     => esc_html__( 'Check to disable Scroll Up', 'verity-pro' ),
        'section'   => 'verity_scrollup',
        'type'      => 'checkbox',
    ) );

    // Update Notifier
    $wp_customize->add_section( 'verity_update_notifier', array(
        'title'    => esc_html__( 'Update Notifier', 'verity-pro' ),
        'panel'    => 'verity_theme_options',
    ) );

    $wp_customize->add_setting( 'verity_update_notifier', array(
        'sanitize_callback' => 'verity_sanitize_checkbox',
    ) );

    $wp_customize->add_control( 'verity_update_notifier', array(
        'label'     => esc_html__( 'Check to disable update notifications', 'verity-pro' ),
        'section'   => 'verity_update_notifier',
        'type'      => 'checkbox',
    ) );
    // Update Notifier End
}
add_action( 'customize_register', 'verity_theme_options' );


/**
 * Returns an array of avaliable fonts registered for Verity Pro
 *
 * @since Verity Pro 1.1
 */
function verity_avaliable_fonts() {
    $avaliable_fonts = array(
        'arial-black' => array(
            'value' => 'arial-black',
            'label' => '"Arial Black", Gadget, sans-serif',
        ),
        'allan' => array(
            'value' => 'allan',
            'label' => '"Allan", sans-serif',
        ),
        'allerta' => array(
            'value' => 'allerta',
            'label' => '"Allerta", sans-serif',
        ),
        'amaranth' => array(
            'value' => 'amaranth',
            'label' => '"Amaranth", sans-serif',
        ),
        'amatic-sc' => array(
            'value' => 'amatic-sc',
            'label' => '"Amatic SC", cursive',
        ),
        'arial' => array(
            'value' => 'arial',
            'label' => 'Arial, Helvetica, sans-serif',
        ),
        'bitter' => array(
            'value' => 'bitter',
            'label' => '"Bitter", sans-serif',
        ),
        'cabin' => array(
            'value' => 'cabin',
            'label' => '"Cabin", sans-serif',
        ),
        'cantarell' => array(
            'value' => 'cantarell',
            'label' => '"Cantarell", sans-serif',
        ),
        'century-gothic' => array(
            'value' => 'century-gothic',
            'label' => '"Century Gothic", sans-serif',
        ),
        'courier-new' => array(
            'value' => 'courier-new',
            'label' => '"Courier New", Courier, monospace',
        ),
        'crimson-text' => array(
            'value' => 'crimson-text',
            'label' => '"Crimson Text", sans-serif',
        ),
        'cuprum' => array(
            'value' => 'cuprum',
            'label' => '"Cuprum", sans-serif',
        ),
        'dancing-script' => array(
            'value' => 'dancing-script',
            'label' => '"Dancing Script", sans-serif',
        ),
        'droid-sans' => array(
            'value' => 'droid-sans',
            'label' => '"Droid Sans", sans-serif',
        ),
        'droid-serif' => array(
            'value' => 'droid-serif',
            'label' => '"Droid Serif", sans-serif',
        ),
        'exo' => array(
            'value' => 'exo',
            'label' => '"Exo", sans-serif',
        ),
        'exo-2' => array(
            'value' => 'exo-2',
            'label' => '"Exo 2", sans-serif',
        ),
        'georgia' => array(
            'value' => 'georgia',
            'label' => 'Georgia, "Times New Roman", Times, serif',
        ),
        'helvetica' => array(
            'value' => 'helvetica',
            'label' => 'Helvetica, "Helvetica Neue", Arial, sans-serif',
        ),
        'helvetica-neue' => array(
            'value' => 'helvetica-neue',
            'label' => '"Helvetica Neue",Helvetica,Arial,sans-serif',
        ),
        'istok-web' => array(
            'value' => 'istok-web',
            'label' => '"Istok Web", sans-serif',
        ),
        'impact' => array(
            'value' => 'impact',
            'label' => 'Impact, Charcoal, sans-serif',
        ),
        'josefin-sans' => array(
            'value' => 'josefin-sans',
            'label' => '"Josefin Sans", sans-serif',
        ),
        'lato' => array(
            'value' => 'lato',
            'label' => '"Lato", sans-serif',
        ),
        'lucida-sans-unicode' => array(
            'value' => 'lucida-sans-unicode',
            'label' => '"Lucida Sans Unicode", "Lucida Grande", sans-serif',
        ),
        'lucida-grande' => array(
            'value' => 'lucida-grande',
            'label' => '"Lucida Grande", "Lucida Sans Unicode", sans-serif',
        ),
        'lobster' => array(
            'value' => 'lobster',
            'label' => '"Lobster", sans-serif',
        ),
        'lora' => array(
            'value' => 'lora',
            'label' => '"Lora", serif',
        ),
        'monaco' => array(
            'value' => 'monaco',
            'label' => 'Monaco, Consolas, "Lucida Console", monospace, sans-serif',
        ),
        'montserrat' => array(
            'value' => 'montserrat',
            'label' => '"Montserrat", sans-serif',
        ),
        'nobile' => array(
            'value' => 'nobile',
            'label' => '"Nobile", sans-serif',
        ),
        'noto-serif' => array(
            'value' => 'noto-serif',
            'label' => '"Noto Serif", serif',
        ),
        'neuton' => array(
            'value' => 'neuton',
            'label' => '"Neuton", serif',
        ),
        'open-sans' => array(
            'value' => 'open-sans',
            'label' => '"Open Sans", sans-serif',
        ),
        'oswald' => array(
            'value' => 'oswald',
            'label' => '"Oswald", sans-serif',
        ),
        'palatino' => array(
            'value' => 'palatino',
            'label' => 'Palatino, "Palatino Linotype", "Book Antiqua", serif',
        ),
        'patua-one' => array(
            'value' => 'patua-one',
            'label' => '"Patua One", sans-serif',
        ),
        'playfair-display' => array(
            'value' => 'playfair-display',
            'label' => '"Playfair Display", sans-serif',
        ),
        'pt-sans' => array(
            'value' => 'pt-sans',
            'label' => '"PT Sans", sans-serif',
        ),
        'pt-serif' => array(
            'value' => 'pt-serif',
            'label' => '"PT Serif", serif',
        ),
        'quattrocento-sans' => array(
            'value' => 'quattrocento-sans',
            'label' => '"Quattrocento Sans", sans-serif',
        ),
        'roboto' => array(
            'value' => 'roboto',
            'label' => '"Roboto", sans-serif',
        ),
        'roboto-slab' => array(
            'value' => 'roboto-slab',
            'label' => '"Roboto Slab", serif',
        ),
        'rubik' => array(
            'value' => 'rubik',
            'label' => '"Rubik", serif',
        ),
        'sans-serif' => array(
            'value' => 'sans-serif',
            'label' => 'Sans Serif, Arial',
        ),
        'source-sans-pro' => array(
            'value' => 'source-sans-pro',
            'label' => '"Source Sans Pro", sans-serif',
        ),
        'tahoma' => array(
            'value' => 'tahoma',
            'label' => 'Tahoma, Geneva, sans-serif',
        ),
        'trebuchet-ms' => array(
            'value' => 'trebuchet-ms',
            'label' => '"Trebuchet MS", "Helvetica", sans-serif',
        ),
        'times-new-roman' => array(
            'value' => 'times-new-roman',
            'label' => '"Times New Roman", Times, serif',
        ),
        'ubuntu' => array(
            'value' => 'ubuntu',
            'label' => '"Ubuntu", sans-serif',
        ),
        'varela' => array(
            'value' => 'varela',
            'label' => '"Varela", sans-serif',
        ),
        'verdana' => array(
            'value' => 'verdana',
            'label' => 'Verdana, Geneva, sans-serif',
        ),
        'yanone-kaffeesatz' => array(
            'value' => 'yanone-kaffeesatz',
            'label' => '"Yanone Kaffeesatz", sans-serif',
        )
    );

    return apply_filters( 'verity_avaliable_fonts', $avaliable_fonts );
}


/**
 * Returns an array of font family options
 *
 * @since Verity Pro 1.1
 */
function verity_font_family_options() {
    $options = array(
        'verity_body_font'         => array(
                                    'label'    => esc_html__( 'Default Font Family', 'verity-pro' ),
                                    'default'  => 'lato',
                                    'selector' => 'body, button, input, select, textarea'
                                ),
        'verity_title_font'        => array(
                                    'label'    => esc_html__( 'Site Title Font Family', 'verity-pro' ),
                                    'default'  => 'playfair-display' ,
                                    'selector' => '.site-title'
                                ),
        'verity_tagline_font'      => array(
                                    'label'    => esc_html__( 'Site Tagline Font Family', 'verity-pro' ),
                                    'default'  => 'lato',
                                    'selector' => '.site-description'
                                ),
        'verity_headings_font'     => array(
                                    'label' => esc_html__( 'Headings Tags from h1 to h6 Font Family', 'verity-pro' ),
                                    'default' => 'lato',
                                    'selector' => 'h1, h2, h3, h4, h5, h6'
                                ),
        'verity_content_title_font'=> array(
                                    'label'    => esc_html__( 'Content Title Font Family', 'verity-pro' ),
                                    'default'  => 'lato',
                                    'selector' => '.page-title, #main .entry-title, #main .entry-subtitle'
                                ),
        'verity_content_font'      => array(
                                    'label'    => esc_html__( 'Content Body Font Family', 'verity-pro' ),
                                    'default'  => 'lato',
                                    'selector' => '#main .entry-content, #main .entry-summary'
                                ),
    );

    return apply_filters( 'verity_font_family_options', $options );
}
