<?php
/**
 * The template for displaying the Slider
 *
 * @package Catch Themes
 * @subpackage Verity Pro
 * @since Verity Pro 1.1
 */

if( !function_exists( 'verity_featured_slider' ) ) :
/**
 * Add slider.
 *
 * @uses action hook verity_before_content.
 *
 * @since Verity Pro 1.1
 */
function verity_featured_slider() {
	$enable_slider = get_theme_mod( 'verity_slider_option', 'disabled' );


	if ( verity_check_section( $enable_slider ) ) {
		$slider_type       = get_theme_mod( 'verity_slider_type', 'demo' );
		$transition_effect = get_theme_mod( 'verity_slider_transition_effect', 'fade' );
		$transition_length = get_theme_mod( 'verity_slider_transition_length', 1 );
		$transition_delay  = get_theme_mod( 'verity_slider_transition_delay', 4 );
		$image_loader      = get_theme_mod( 'verity_slider_image_loader', true );

		$output = '
			<div id="feature-slider" class="section">
				<div class="wrapper">
					<div class="cycle-slideshow"
					    data-cycle-log="false"
					    data-cycle-pause-on-hover="true"
					    data-cycle-swipe="true"
					    data-cycle-auto-height=container
					    data-cycle-fx="'. esc_attr( $transition_effect ) .'"
						data-cycle-speed="'. esc_attr( $transition_length * 1000 ) .'"
						data-cycle-timeout="'. esc_attr( $transition_delay * 1000 ) .'"
						data-cycle-loader=false
						data-cycle-slides="> article"
						>

					    <!-- prev/next links -->
					    <button class="cycle-prev" aria-label="Previous">' .verity_get_svg( array( 'icon' => 'angle-down' ) ) . '</button>
					    <button class="cycle-next" aria-label="Next">' .verity_get_svg( array( 'icon' => 'angle-down' ) ) . '</button>

					    <!-- empty element for pager links -->
    					<div class="cycle-pager"></div>';
						// Select Slider
						if ( 'demo' == $slider_type ) {
							$output .= verity_demo_slider();
						}
						else if ( 'post' == $slider_type || 'page' == $slider_type || 'category' == $slider_type ) {
							$output .= verity_post_page_category_slider();
						}
						elseif ( 'image' == $slider_type ) {
							$output .= verity_image_slider();
						}

		$output .= '
					</div><!-- .cycle-slideshow -->
				</div><!-- .wrapper -->
			</div><!-- #feature-slider -->';

		echo $output;
	}
}
endif;
add_action( 'verity_slider', 'verity_featured_slider', 10 );


if ( ! function_exists( 'verity_demo_slider' ) ) :
	/**
	 * This function to display featured posts slider
	 *
	 * @get the data value from customizer options
	 *
	 * @since Verity Pro 1.1
	 *
	 */
	function verity_demo_slider() {
		return '
		<article class="post demo-image-1 hentry slides displayblock">
			<div class="slider-image-wrapper">
				<div class="slider-image-thumbnail" style="background-image: url(' .get_template_directory_uri().'/assets/images/slider1-1920x800.jpg);"></div>
			</div>
			<div class="slider-content-wrapper">
				<div class="entry-container">
					<header class="entry-header">
						<h2 class="entry-title">
							<a href="#"><span>Mountain</span></a>
						</h2>
						<p class="entry-meta screen-reader-text">
							<span class="cat-links">
								<span class="screen-reader-text">Categories</span>
								<a rel="category tag" href="#">Travel</a>
							</span>
							<span class="posted-on">
								<span class="screen-reader-text">Posted on</span>

								<a rel="bookmark" href="#">
									<time datetime="2016-05-15T04:29:55+00:00" class="entry-date published">May 7, 2016</time>

									<time datetime="2016-05-08T08:47:27+00:00" class="updated">May 7, 2016</time>
								</a>
							</span>
						</p><!-- .entry-meta -->
					</header>
					<div class="entry-summary">
						<p><a href="#" class="more-link"><span>Continue reading</span></a></p>
					</div><!-- .entry-summary -->
				</div><!-- .entry-container -->
			</div><!-- .slider-content-wrapper -->
		</article><!-- .slides -->

		<article class="post demo-image-2 hentry slides displaynone">
			<div class="slider-image-wrapper">
				<div class="slider-image-thumbnail" style="background-image: url(' .get_template_directory_uri().'/assets/images/slider2-1920x800.jpg);"></div>
			</div>
			<div class="slider-content-wrapper">
				<div class="entry-container">
					<header class="entry-header">
						<h2 class="entry-title">
							<a href="#"><span>Ocean</span></a>
						</h2>
						<p class="entry-meta screen-reader-text">
							<span class="cat-links">
								<span class="screen-reader-text">Categories</span>
								<a rel="category tag" href="#">Travel</a>
							</span>
							<span class="posted-on">
								<span class="screen-reader-text">Posted on</span>

								<a rel="bookmark" href="#">
									<time datetime="2016-05-15T04:29:55+00:00" class="entry-date published">May 7, 2016</time>

									<time datetime="2016-05-08T08:47:27+00:00" class="updated">May 7, 2016</time>
								</a>
							</span>
						</p><!-- .entry-meta -->
					</header>
					<div class="entry-summary">
						<p><a href="#" class="more-link"><span>Continue reading</span></a></p>
					</div><!-- .entry-summary -->
				</div><!-- .entry-container -->
			</div><!-- .slider-content-wrapper -->
		</article><!-- .slides -->';
	}
endif; // verity_demo_slider


if ( ! function_exists( 'verity_post_page_category_slider' ) ) :
	/**
	 * This function to display featured posts/page/category slider
	 *
	 * @param $options: verity_theme_options from customizer
	 *
	 * @since Verity Pro 1.1
	 */
	function verity_post_page_category_slider() {
		$quantity     = get_theme_mod( 'verity_slider_number', 4 );
		$no_of_post   = 0; // for number of posts
		$post_list    = array();// list of valid post/page ids
		$type         = get_theme_mod( 'verity_slider_type' );
		$show_content = get_theme_mod( 'verity_slider_content_show', 'excerpt' );
		$output     = '';

		$args = array(
			'post_type'           => 'any',
			'orderby'             => 'post__in',
			'ignore_sticky_posts' => 1 // ignore sticky posts
		);

		//Get valid number of posts
		if( 'post' == $type || 'page' == $type  ) {
			for( $i = 1; $i <= $quantity; $i++ ){
				$post_id = '';

				if( 'post' == $type ) {
					$post_id = get_theme_mod( 'verity_slider_post_' . $i );
				}
				elseif( 'page' == $type ) {
					$post_id = get_theme_mod( 'verity_slider_page_' . $i );
				}

				if ( $post_id && '' != $post_id ) {
					$post_list = array_merge( $post_list, array( $post_id ) );

					$no_of_post++;
				}
			}

			$args['post__in'] = $post_list;
		}
		elseif( 'category' == $type ) {
			$no_of_post = $quantity;

			$args['category__in'] = get_theme_mod( 'verity_slider_select_category' );

			$args['post_type'] = 'post';
		}

		if ( 0 == $no_of_post ) {
			return;
		}

		$args['posts_per_page'] = $no_of_post;

		$loop = new WP_Query( $args );

		while ( $loop->have_posts()) :
			$loop->the_post();

			$title_attribute = the_title_attribute( 'echo=0' );

			if ( 0 == $loop->current_post ) {
				$classes = 'post post-' . esc_attr( get_the_ID() ) . ' hentry slides displayblock';
			} else {
				$classes = 'post post-' . esc_attr( get_the_ID() ) . ' hentry slides displaynone';
			}

			//Default value if there is no featurd image or first image
			$image_url = get_template_directory_uri(). '/assets/images/no-featured-image-1920x800.jpg';

			if ( has_post_thumbnail() ) {
				$image_url = get_the_post_thumbnail_url( get_the_ID(), 'verity-slider' );
			}
			else {
				//Get the first image in page, returns false if there is no image
				$first_image_url = verity_get_first_image( get_the_ID(), 'verity-slider', '', true );

				//Set value of image as first image if there is an image present in the page
				if ( '' != $first_image_url ) {
					$image_url = $first_image_url;
				}
			}


			$output .= '
			<article class="' . $classes . '">';
				$output .= '
				<div class="slider-image-wrapper">
					<div class="slider-image-thumbnail" style="background-image: url(' . esc_url( $image_url ) . ');"></div>
				</div><!-- .slider-image-wrapper -->

				<div class="slider-content-wrapper">
					<div class="entry-container">
						<header class="entry-header">
							<h2 class="entry-title">
								<a title="' . $title_attribute . '" href="' . esc_url( get_permalink() ) . '">'.the_title( '<span>','</span>', false ).'</a>
							</h2>
						</header>
							';

						if ( 'excerpt' == $show_content ) {
							$excerpt = get_the_excerpt();

							$output .= '<div class="entry-summary"><p>' . $excerpt . '</p></div><!-- .entry-summary -->';
						} elseif ( 'full-content' == $show_content ) {
							$content = apply_filters( 'the_content', get_the_content() );
							$content = str_replace( ']]>', ']]&gt;', $content );
							$output .= '<div class="entry-content">' . $content . '</div><!-- .entry-content -->';
						}

						$output .= '
					</div><!-- .entry-container -->
				</div><!-- .slider-content-wrapper -->
			</article><!-- .slides -->';
		endwhile;

		wp_reset_postdata();

		return $output;
	}
endif; // verity_post_page_category_slider


if ( ! function_exists( 'verity_image_slider' ) ) :
/**
 * This function to display featured posts slider
 *
 * @get the data value from theme options
 * @displays on the index
 *
 * @useage Featured Image, Title and Excerpt of Post
 *
 */
function verity_image_slider() {
	$quantity	= get_theme_mod( 'verity_slider_number', 4 );

	$output = '';

	for ( $i = 1; $i <= $quantity; $i++ ) {
		//Check Image Not Empty to add in the slides
		if ( $image = get_theme_mod(  'verity_slider_image_'. $i ) )  {
			$imagetitle = 'Featured Image-'.$i;

			//Checking Title
			if ( get_theme_mod(  'verity_featured_title_'. $i ) ) {
				$imagetitle = get_theme_mod(  'verity_featured_title_'. $i );
			}

			$title   = '';

			$raw_title = get_theme_mod( 'verity_featured_title_'. $i );

			$link   = '#';
			$target = '_self';

			if ( get_theme_mod(  'verity_featured_link_'. $i ) ) {
				$link = get_theme_mod(  'verity_featured_link_'. $i );

				//Checking Link Target
				if ( get_theme_mod(  'verity_featured_target_'. $i ) ) {
					$target = '_blank';
				}

				$title = '<header class="entry-header"><h2 class="entry-title"><a title="' . esc_attr( $raw_title ) . '" href="' . esc_url( $link ) . '" target="' . $target . '"><span>' . esc_attr( $raw_title ) . '</span></a></h2></header>';
			} else if ( $raw_title ) {
				$title = '<header class="entry-header"><h2 class="entry-title"><span>' . esc_attr( $raw_title ) . '</span></h2></header>';
			}

			$content = '';
			//Checking Content
			if ( $raw_content = get_theme_mod( 'verity_featured_content_'. $i ) ) {
				$content = '<div class="entry-summary"><p>' . $raw_content . '</p></div><!-- .entry-summary -->';
			}

			$contentopening = '';
			$contentclosing = '';

			//Content Opening and Closing
			if ( !empty ( $title ) || !empty ( $content ) ) {
				$contentopening = '<div class="slider-content-wrapper"><div class="entry-container">';
				$contentclosing = '</div><!-- .entry-container --></div><!-- .slider-content-wrapper -->';
			}


			//Adding in Classes for Display block and none
			if ( 1 == $i ) {
				$classes = 'displayblock';
			} else {
				$classes = 'displaynone';
			}

			$output .= '
			<article class="image-slides hentry slider-image images-' . esc_attr( $i ) . ' slides  ' . $classes  .'">
				<div class="slider-image-wrapper">
					<div class="slider-image-thumbnail" style="background-image: url('. esc_url( $image ) .');"></div>
				</div>
				' . $contentopening . $title . $content . $contentclosing . '
			</article><!-- .slides --> ';
		}
	}
	return $output;
}
endif; //verity_image_slider
