<?php
/**
 * Adding support for WooCommerce Plugin
 */

if ( ! class_exists( 'woocommerce' ) ) {
    // Bail if WooCommerce is not installed
    return;
}


if ( ! function_exists( 'verity_woocommerce_setup' ) ) :
    /**
     * Sets up support for various WooCommerce features.
     */
    function verity_woocommerce_setup() {
        add_theme_support( 'woocommerce' );

        if ( ! get_theme_mod( 'verity_product_gallery_zoom' ) ) {
            add_theme_support('wc-product-gallery-zoom');
        }

        if ( ! get_theme_mod( 'verity_product_gallery_lightbox' ) ) {
            add_theme_support('wc-product-gallery-lightbox');
        }

        if ( ! get_theme_mod( 'verity_product_gallery_slider' ) ) {
            add_theme_support('wc-product-gallery-slider');
        }
    }
endif; //verity_woocommerce_setup
add_action( 'after_setup_theme', 'verity_woocommerce_setup' );


/**
 * Add WooCommerce Options to customizer
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function verity_woocommerce_options( $wp_customize ) {
    $wp_customize->add_setting( 'verity_woocommerce_layout', array(
        'default'           => 'no-sidebar-full-width',
        'sanitize_callback' => 'verity_sanitize_select',
    ) );

    $wp_customize->add_control( 'verity_woocommerce_layout', array(
        'description' => esc_html__( 'Layout for WooCommerce Pages', 'verity-pro' ),
        'label'       => esc_html__( 'WooCommerce Layout', 'verity-pro' ),
        'section'     => 'verity_layout_options',
        'type'        => 'radio',
        'choices'     => array(
            'left-sidebar'          => esc_html__( 'Left Sidebar ( Primary Sidebar, Content )', 'verity-pro' ),
            'no-sidebar'            => esc_html__( 'No Sidebar', 'verity-pro' ),
            'no-sidebar-full-width' => esc_html__( 'No Sidebar: Full Width', 'verity-pro' ),
            'right-sidebar'         => esc_html__( 'Right Sidebar ( Content, Primary Sidebar )', 'verity-pro' ),
        ),
    ) );

    // WooCommerce Options
    $wp_customize->add_section( 'verity_woocommerce_options', array(
        'title'       => esc_html__( 'WooCommerce Options', 'verity-pro' ),
        'panel'       => 'verity_theme_options',
        'description' => esc_html__( 'Since these options are added via theme support, you will need to save and refresh the customizer to view the full effect.', 'verity-pro' ),
    ) );

    $wp_customize->add_setting( 'verity_product_gallery_zoom', array(
        'sanitize_callback' => 'verity_sanitize_checkbox',
    ) );

    $wp_customize->add_control( 'verity_product_gallery_zoom', array(
        'label'   => esc_html__( 'Check to disable Product Gallery Zoom', 'verity-pro' ),
        'section' => 'verity_woocommerce_options',
        'type'    => 'checkbox',
    ) );

    $wp_customize->add_setting( 'verity_product_gallery_lightbox', array(
        'sanitize_callback' => 'verity_sanitize_checkbox',
    ) );

    $wp_customize->add_control( 'verity_product_gallery_lightbox', array(
        'label'   => esc_html__( 'Check to disable Product Gallery Lightbox', 'verity-pro' ),
        'section' => 'verity_woocommerce_options',
        'type'    => 'checkbox',
    ) );

    $wp_customize->add_setting( 'verity_product_gallery_slider', array(
        'sanitize_callback' => 'verity_sanitize_checkbox',
    ) );

    $wp_customize->add_control( 'verity_product_gallery_slider', array(
        'label'   => esc_html__( 'Check to disable Product Gallery Slider', 'verity-pro' ),
        'section' => 'verity_woocommerce_options',
        'type'    => 'checkbox',
    ) );
}
add_action( 'customize_register', 'verity_woocommerce_options' );


/**
 * uses remove_action to remove the WooCommerce Wrapper and add_action to add Main Wrapper
 */
remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10 );
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10 );


if ( ! function_exists( 'verity_woocommerce_start' ) ) :
    function verity_woocommerce_start() {
    	echo '<div id="primary" class="content-area"><main role="main" class="site-main woocommerce" id="main"><div class="woocommerce-posts-wrapper">';
    }
endif; //verity_woocommerce_start
add_action( 'woocommerce_before_main_content', 'verity_woocommerce_start', 15 );


if ( ! function_exists( 'verity_woocommerce_end' ) ) :
    function verity_woocommerce_end() {
    	echo '</div><!-- .woocommerce-posts-wrapper --></main><!-- #main --></div><!-- #primary -->';
    }
endif; //verity_woocommerce_end
add_action( 'woocommerce_after_main_content', 'verity_woocommerce_end', 15 );


function verity_woocommerce_title_icon() { ?>
	<div class="square"><?php echo verity_get_svg( array( 'icon' => 'square' ) ); ?><span class="screen-reader-text"><?php esc_html_e( 'Square', 'verity-pro' ); ?></span></div>
    <?php 
}
add_action( 'woocommerce_archive_description', 'verity_woocommerce_title_icon', 5 );


function verity_woocommerce_shorting_start() { 
	echo '<div class="woocommerce-shorting-wrapper">';
}
add_action( 'woocommerce_before_shop_loop', 'verity_woocommerce_shorting_start', 10 );


function verity_woocommerce_shorting_end() { 
	echo '</div><!-- .woocommerce-shorting-wrapper -->';
}
add_action( 'woocommerce_before_shop_loop', 'verity_woocommerce_shorting_end', 40 );


function verity_woocommerce_product_container_start() { 
	echo '<div class="product-container">';
}
add_action( 'woocommerce_before_shop_loop_item_title', 'verity_woocommerce_product_container_start', 20 );


function verity_woocommerce_product_container_end() { 
	echo '</div><!-- .product-container -->';
}
add_action( 'woocommerce_after_shop_loop_item', 'verity_woocommerce_product_container_end', 20 );

/**
 * Remove breadcrumb from default position
 * Check template-parts/header/breadcrumb.php
 */
function verity_remove_wc_breadcrumbs() {
    remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20, 0 );
}
add_action( 'init', 'verity_remove_wc_breadcrumbs' );