<?php
/**
 * The template used for displaying hero content
 *
 * @package Verity Pro
 */

$enable_section = get_theme_mod( 'verity_hero_content_visibility', 'homepage' );

if ( ! verity_check_section( $enable_section ) ) {
	// Bail if hero content is not enabled
	return;
}

$type = get_theme_mod( 'verity_hero_content_type', 'page' );

if ( 'page' == $type || 'post' == $type || 'category' == $type ) :
	$args = array();

	if ( 'page' == $type && $id = get_theme_mod( 'verity_hero_content' ) ) {
		$args['page_id'] = absint( $id );
	} elseif ( 'post' == $type && $id = get_theme_mod( 'verity_hero_content_post' ) ) {
		$args['p'] = absint( $id );
	} elseif( 'category' == $type && $cat = get_theme_mod( 'verity_hero_content_category' ) ) {
		$args['cat'] = absint( $cat );
	}

	// If $args is empty return false
	if ( empty( $args ) ) {
		return;
	}

	// Create a new WP_Query using the argument previously created
	$hero_query = new WP_Query( $args );
	if ( $hero_query->have_posts() ) :
		while ( $hero_query->have_posts() ) : 
			$hero_query->the_post();
			?>
			<div class="hero-content-wrapper section">
				<div class="section-content-wrap">
					<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
						<?php if ( has_post_thumbnail() ) : ?>
							<div class="post-thumbnail hero-image">
								<a href="<?php the_permalink(); ?>">
									<?php the_post_thumbnail( 'verity-hero-image' ); ?>
								</a>
							</div><!-- .hero-image -->
						<?php endif; ?>
						<div class="entry-container">
							<?php if( ! get_theme_mod( 'verity_disable_hero_content_title' ) ) : ?>
							<header class="entry-header">
								<?php the_title( '<h2 class="entry-title">', '</h2>' ); ?>
							</header><!-- .entry-header -->
							<?php endif; ?>

							<div class="entry-content">
								<?php
									the_content();

									wp_link_pages( array(
										'before'      => '<div class="page-links"><span class="page-links-title">' . __( 'Pages:', 'verity-pro' ) . '</span>',
										'after'       => '</div>',
										'link_before' => '<span class="page-number">',
										'link_after'  => '</span>',
										'pagelink'    => '<span class="screen-reader-text">' . __( 'Page', 'verity-pro' ) . ' </span>%',
										'separator'   => '<span class="screen-reader-text">, </span>',
									) );
								?>
							</div><!-- .entry-content -->

							<?php if ( get_edit_post_link() ) : ?>
								<footer class="entry-footer">
									<?php
										edit_post_link(
											sprintf(
												/* translators: %s: Name of current post */
												esc_html__( 'Edit %s', 'verity-pro' ),
												the_title( '<span class="screen-reader-text">"', '"</span>', false )
											),
											'<span class="edit-link">',
											'</span>'
										);
									?>
								</footer><!-- .entry-footer -->
							<?php endif; ?>
						</div><!-- .entry-container -->
					</article><!-- #post-## -->
				</div><!-- .section-content-wrap -->	
			</div><!-- .section -->
		<?php
		endwhile;	
		
		wp_reset_postdata();
	endif;
else: ?>
	
	<div class="hero-content-wrapper section">
		<div class="section-content-wrap">
			<article id="post-0" <?php post_class(); ?>>
				<?php $image = get_theme_mod( 'verity_hero_content_image' ); ?>
				<?php if ( $image ) : ?>
					<div class="post-thumbnail hero-image">
						<?php $link = get_theme_mod( 'verity_hero_content_link' ); ?>
						<?php if ( $link ) : ?>
							<?php $target = get_theme_mod( 'verity_hero_content_target' ) ? '_blank' : '_self'; ?>
							<a href="<?php echo esc_url( $link ); ?>" target="<?php echo esc_attr( $target ); ?>">
						<?php endif; ?>
							
							<img src="<?php echo esc_url( $image ); ?>" class="wp-post-image">
						
						<?php if ( $link ) : ?> 
							</a>
						<?php endif; ?>
					</div><!-- .hero-image -->
				<?php endif; ?>
				<div class="entry-container">
					<?php if( $title = get_theme_mod( 'verity_hero_content_title' ) ) : ?>
						<header class="entry-header">
							<?php echo $title; ?>
						</header><!-- .entry-header -->
					<?php endif; ?>

					<?php if( $content = get_theme_mod( 'verity_hero_content_content' ) ) : ?>
						<div class="entry-content">
							<p>
								<?php echo $content; ?>

								<?php 
									$more_text   = get_theme_mod( 'verity_hero_content_more_text' );
									$more_link   = get_theme_mod( 'verity_hero_content_more_link', '#' );
									$more_target = get_theme_mod( 'verity_hero_content_more_target' ) ? '_blank' : '_self' ;


									if( $more_text ) : ?>
										<a class="more-link" href="<?php echo esc_url( $more_link ); ?>" target="<?php echo esc_attr( $target ); ?>">
											<span><?php echo $more_text; ?></span>
										</a>
									<?php endif; 
								?>
							</p>
						</div><!-- .entry-content -->
					<?php endif; ?>
				</div><!-- .entry-container -->
			</article><!-- #post-## -->
		</div><!-- .section-content-wrap -->	
	</div><!-- .section -->
<?php
endif;