<?php
/**
 * The template for displaying featured content
 *
 * @package Verity
 */

$def_content = 'disabled';
$def_type    = 'category';

if ( class_exists( 'Jetpack' ) ) {
	$def_content = 'homepage';
	$def_type    = 'tag';
}

$enable_content = get_theme_mod( 'verity_featured_content_option', $def_content );

if ( ! verity_check_section( $enable_content ) ) {
	// Bail if featured content is disabled.
	return;
}

$type = get_theme_mod( 'verity_featured_content_type', $def_type );

if ( 'image' !== $type ) {
	$featured_posts = verity_get_featured_posts();

	if ( empty( $featured_posts ) ) {
		return;
	}
}

$title     = get_theme_mod( 'verity_featured_content_archive_title', esc_html__( 'Featured', 'verity-pro' ) );
$sub_title = get_theme_mod( 'verity_featured_content_sub_title' );
$layout    = get_theme_mod( 'verity_featured_content_layout', 'layout-three' );
?>

<div class="featured-content-wrapper section <?php echo esc_attr( $layout ); ?>">

	<?php if ( '' != $title || $sub_title ) : ?>
		<div class="section-heading-wrap">
			<?php if ( '' != $title ) : ?>
			<h2 class="section-title"><?php echo wp_kses_post( $title ); ?></h2>
			<?php endif; ?>

			<?php if ( $sub_title ) : ?>
				<p class="section-subtitle"><?php echo wp_kses_post( $sub_title ); ?></h2>
			<?php endif; ?>
		</div><!-- .section-heading-wrap -->
	<?php endif; ?>

	<div class="section-content-wrap">
		<div class="curve"><?php echo verity_get_svg( array( 'icon' => 'curve' ) ); ?><span class="screen-reader-text"><?php esc_html_e( 'Curve', 'verity-pro' ); ?></span></div>
		<?php
		if ( 'image' === $type ) {
			get_template_part( 'template-parts/featured-content/content', 'featured-content-image' );
		} else {
			foreach ( $featured_posts as $post ) {
				setup_postdata( $post );

				// Include the featured content template.
				get_template_part( 'template-parts/featured-content/content', 'featured-content' );
			}

			wp_reset_postdata();
		}
		?>
	</div><!-- .section-content-wrap -->
</div><!-- .section -->
